#!/bin/sh
export PATH='/build/haskell-doctest-discover/src/doctest-discover-04b6b1f9fa93518e49d7a95052e6efc2d2d2dabe/dist/build/doctest-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/build/haskell-doctest-discover/src/doctest-discover-04b6b1f9fa93518e49d7a95052e6efc2d2d2dabe/dist/build/doctest-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
'/usr/bin/ghc-pkg-9.6.6' 'unregister' '--force' '--global' 'doctest-discover-0.2.0.0' "$@"
